diff flys-artifacts/src/main/java/de/intevation/flys/artifacts/FLYSArtifact.java @ 1809:f6a190f6aaff

Give outputname to artifacts getInitialFacetActivity, generate second pair of MainvalueFacets for discharge curves. flys-artifacts/trunk@3138 c6561f87-3c4e-4783-a992-168aeb5c3f6f
author Felix Wolfsteller <felix.wolfsteller@intevation.de>
date Wed, 02 Nov 2011 11:21:57 +0000
parents 376c81aa7d55
children 1be3a4636ee3
line wrap: on
line diff
--- a/flys-artifacts/src/main/java/de/intevation/flys/artifacts/FLYSArtifact.java	Wed Nov 02 11:15:00 2011 +0000
+++ b/flys-artifacts/src/main/java/de/intevation/flys/artifacts/FLYSArtifact.java	Wed Nov 02 11:21:57 2011 +0000
@@ -1045,13 +1045,18 @@
      * selection in Client ThemeList GUI). This will be checked one time
      * when the facet enters a collections describe document.
      *
      * @param facetName name of the facet.
      * @param index     index of the facet.
      *
      * @return 1 if wished to be initally active, 0 if not. FLYSArtifact
      *         defaults to "1".
      */
-    public int getInitialFacetActivity(String facetName, int index) {
+    public int getInitialFacetActivity(
+        String outputName,
+        String facetName,
+        int index)
+    {
         return 1;
     }
 }
@@ -1045,13 +1045,18 @@
      * when the facet enters a collections describe document.
      *
-     * @param facetName name of the facet.
-     * @param index     index of the facet.
+     * @param facetName  name of the facet.
+     * @param outputName name of the output.
+     * @param index      index of the facet.
      *
      * @return 1 if wished to be initally active, 0 if not. FLYSArtifact

http://dive4elements.wald.intevation.org